@@ -46,6 +46,12 @@
 #include <Rinterface.h>
 #include <Rdevices.h>    /* for KillAllDevices */
 #include <R_ext/Print.h> /* for Rprintf */
+#include <Rversion.h>
+#if defined(R_VERSION) && R_VERSION >= R_Version(2, 7, 0)
+# define CONST const
+#else
+# define CONST
+#endif
 
 #include "gtkconsole.h"
 #include "terminal.h"
@@ -64,7 +70,7 @@ static void Rgnome_CleanUp(SA_TYPE saveact, int status, int runLast);
  *  1) FATAL MESSAGES AT STARTUP
  */
 
-static void Rgnome_Suicide(char *s)
+static void Rgnome_Suicide(CONST char *s)
 {
     GtkWidget *dialog;
     gchar *message;
@@ -208,7 +214,7 @@ static void Rgnome_CleanUp(SA_TYPE saveact, int status, int runLast)
     exit(status);
 }
 
-static void Rgnome_ShowMessage(char *s)
+static void Rgnome_ShowMessage(CONST char *s)
 {
     GtkWidget *dialog;
 
